@@ -10,7 +10,7 @@ WZ_ld<-function(marker_ld, marker_pvalues){
 
   z_scores <- qnorm(1 - marker_pvalues)
   
-  weights <- rowMeans(marker_ld)  
+  weights <- rowMeans(as.matrix(marker_ld))  
   
   weighted_z_score <- sum(z_scores * weights) / sqrt(sum(weights^2))
   
