@@ -8,7 +8,7 @@
 
 meta_LD<-function(marker_ld, marker_pvalues){
  
-  weights <- rowMeans(marker_ld) 
+  weights <- rowMeans(as.matrix(marker_ld)) 
   
   weighted_average_pvalue <- sum(marker_pvalues * weights) / sum(weights)
   
